#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_analysis_case import ABQAnalysisCase
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQAnalysisCases(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQAnalysisCases
                | 
                | The collection of ABQAQUS analysis case objects attached to an
                | ABQAnalysisModel object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQAnalysisCase)
        self.abq_analysis_cases = com_object

    def add(self, i_analysis_type: str) -> ABQAnalysisCase:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iAnalysisType) As ABQAnalysisCase
                | 
                |     Creates a new Abaqus analysis case and adds it to the collection of Abaqus
                |     analysis cases.
                | 
                |     Parameters:
                | 
                |         iAnalysisType
                |             The type of Analysis Case to create.
                | 
                |             Legal values:
                | 
                |             "STRUCTURAL"
                |             "THERMAL"
                |             "EXPLICIT_DYNAMICS"
                | 
                |     Returns:
                |         The Abaqus analysis case object that was created. 
                |     Example:
                |         The following example creates an Abaqus analysis case
                |         abqCase1:
                | 
                |          Dim abqCases As ABQAnalysisCases
                |          Dim abqCase1 As ABQAnalysisCase
                |          Set abqCase1 =  abqCases.Add("STRUCTURAL")

        :param str i_analysis_type:
        :rtype: ABQAnalysisCase
        """
        return ABQAnalysisCase(self.abq_analysis_cases.Add(i_analysis_type))

    def item(self, i_index: cat_variant) -> ABQAnalysisCase:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQAnalysisCase
                | 
                |     Returns an Abaqus analysis case using its index or its name from the
                |     ABQAnalysisCases collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus analysis case to retrieve from
                |             the collection of Abaqus analysis cases. If the index is a number, it specifies
                |             the rank of the Abaqus analysis case in the collection. The index of the first
                |             Abaqus analysis case in the collection is 1, and the index of the last case is
                |             Count. If the index is a string, it specifies the name you assigned to the case
                |             using the CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQIAABQAnalysisCase. 
                |     Example:
                |         This example retrieves the fifth Abaqus analysis case in the collection
                |         and saves it in a variable called ThisCase. The example also retrieves the
                |         Abaqus analysis case named "MyCase" in the collection and saves it in a
                |         variable called ThatCase.
                | 
                |          Set CaseColl = AnalysisDoc.ABQAnalysisModel.Cases
                |          Set ThisCase = CaseColl.Item(5)
                |          Set ThatCase = CaseColl.Item("MyCase")

        :param cat_variant i_index:
        :rtype: ABQAnalysisCase
        """
        return ABQAnalysisCase(self.abq_analysis_cases.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Abaqus analysis case using its index or its name from the
                |     collection of Abaqus analysis cases. This function works only in CAAV5 R13
                |     onwards.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus analysis case to retrieve from
                |             the collection of Abaqus analysis cases. If the index is a number, it specifies
                |             the rank of the Abaqus analysis case in the collection. The index of the first
                |             Abaqus analysis case in the collection is 1, and the index of the last analysis
                |             case is Count. If the index is a string, it specifies the name you assigned to
                |             the analysis case using the CATIABase::Name
                |             property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_analysis_cases.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_analysis_cases)
        # #     Dim iIndex (2)
        # #     abq_analysis_cases.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQAnalysisCases(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class PlugMapViewSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         PlugMapViewSettingAtt
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement DNBIAPlugMapViewSettingAtt are
                | ...
                | 
                | Do not use the DNBIAPlugMapViewSettingAtt interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.plug_map_view_setting_att = com_object

    @property
    def logical_data_attr_list(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LogicalDataAttrList() As CATSafeArrayVariant
                | 
                |     Returns or sets the LogicalDataAttrList parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is
                |     delegated.

        :rtype: tuple
        """

        return self.plug_map_view_setting_att.LogicalDataAttrList

    @logical_data_attr_list.setter
    def logical_data_attr_list(self, value: tuple):
        """
        :param tuple value:
        """

        self.plug_map_view_setting_att.LogicalDataAttrList = value

    @property
    def termination_attr_list(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TerminationAttrList() As CATSafeArrayVariant
                | 
                |     Returns or sets the ConstraintsSimul parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is
                |     delegated.

        :rtype: tuple
        """

        return self.plug_map_view_setting_att.TerminationAttrList

    @termination_attr_list.setter
    def termination_attr_list(self, value: tuple):
        """
        :param tuple value:
        """

        self.plug_map_view_setting_att.TerminationAttrList = value

    def addto_logical_data_attr_list(self, iparameter_name: str, i_refparam_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddtoLogicalDataAttrList(CATBSTR iparameterName,
                | CATBSTR iRefparamName)
                | 
                |     Method to add a parameter to the LogicalDataAttrList.

        :param str iparameter_name:
        :param str i_refparam_name:
        :rtype: None
        """
        return self.plug_map_view_setting_att.AddtoLogicalDataAttrList(iparameter_name, i_refparam_name)

    def addto_termination_attr_list(self, iparameter_name: str, i_refparam_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddtoTerminationAttrList(CATBSTR iparameterName,
                | CATBSTR iRefparamName)
                | 
                |     Method to add a parameter to the TerminationAttrList.

        :param str iparameter_name:
        :param str i_refparam_name:
        :rtype: None
        """
        return self.plug_map_view_setting_att.AddtoTerminationAttrList(iparameter_name, i_refparam_name)

    def get_logical_data_attr_list_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLogicalDataAttrListInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LogicalDataAttrList
                |     parameter.
                |     Role:Retrieves the state of the LogicalDataAttrList parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a
                |             reset.
                |         ioLocked
                |             Indicates if the parameter has been locked.
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.plug_map_view_setting_att.GetLogicalDataAttrListInfo(io_admin_level, io_locked)

    def get_termination_attr_list_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTerminationAttrListInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TerminationAttrList
                |     parameter.
                |     Role:Retrieves the state of the TerminationAttrList parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a
                |             reset.
                |         ioLocked
                |             Indicates if the parameter has been locked.
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.plug_map_view_setting_att.GetTerminationAttrListInfo(io_admin_level, io_locked)

    def remove_from_logical_data_attr_list(self, iparameter_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovefromLogicalDataAttrList(CATBSTR iparameterName)
                | 
                |     Method to Remove a parameter fron the LogicalDataAttrList.

        :param str iparameter_name:
        :rtype: None
        """
        return self.plug_map_view_setting_att.RemovefromLogicalDataAttrList(iparameter_name)

    def remove_from_termination_attr_list(self, iparameter_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovefromTerminationAttrList(CATBSTR iparameterName)
                | 
                |     Method to Remove a parameter fron the TerminationAttrList.

        :param str iparameter_name:
        :rtype: None
        """
        return self.plug_map_view_setting_att.RemovefromTerminationAttrList(iparameter_name)

    def set_logical_data_attr_list_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLogicalDataAttrListLock(boolean iLocked)
                | 
                |     Locks or unlocks the LogicalDataAttrList parameter.
                |     Role:Locks or unlocks the LogicalDataAttrList parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.plug_map_view_setting_att.SetLogicalDataAttrListLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_logical_data_attr_list_lock'
        # # vba_code = """
        # # Public Function set_logical_data_attr_list_lock(plug_map_view_setting_att)
        # #     Dim iLocked (2)
        # #     plug_map_view_setting_att.SetLogicalDataAttrListLock iLocked
        # #     set_logical_data_attr_list_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_termination_attr_list_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTerminationAttrListLock(boolean iLocked)
                | 
                |     Locks or unlocks the TerminationAttrList parameter.
                |     Role:Locks or unlocks the TerminationAttrList parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.plug_map_view_setting_att.SetTerminationAttrListLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_termination_attr_list_lock'
        # # vba_code = """
        # # Public Function set_termination_attr_list_lock(plug_map_view_setting_att)
        # #     Dim iLocked (2)
        # #     plug_map_view_setting_att.SetTerminationAttrListLock iLocked
        # #     set_termination_attr_list_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PlugMapViewSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeTranslate(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeTranslate
                | 
                | Represents the hybrid shape translate feature object.
                | Role: To access the data of the hybrid shape translate feature object. This
                | data includes:
                | 
                |     The element to translate
                |     The translation direction
                |     The translation distance and its value
                | 
                | LICENSING INFORMATION: Creation of volume result requires GSO
                | License
                | if GSO License is not granted , setting of Volume context has not
                | effect
                | 
                | Use the CATIAHybridShapeFactory to create HybridShapeFeature
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_translate = com_object

    @property
    def coord_x_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CoordXValue() As double
                | 
                |     Returns or sets the translate X coordinate value.

        :rtype: float
        """

        return self.hybrid_shape_translate.CoordXValue

    @coord_x_value.setter
    def coord_x_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_translate.CoordXValue = value

    @property
    def coord_y_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CoordYValue() As double
                | 
                |     Returns or sets the translate Y coordinate value.

        :rtype: float
        """

        return self.hybrid_shape_translate.CoordYValue

    @coord_y_value.setter
    def coord_y_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_translate.CoordYValue = value

    @property
    def coord_z_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CoordZValue() As double
                | 
                |     Returns or sets the translate Z coordinate value.

        :rtype: float
        """

        return self.hybrid_shape_translate.CoordZValue

    @coord_z_value.setter
    def coord_z_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_translate.CoordZValue = value

    @property
    def direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Direction() As HybridShapeDirection
                | 
                |     Returns or sets the translate direction.
                | 
                |     Example
                |         This example retrieves in Dir the translation direction for the
                |         Translate hybrid shape feature.
                | 
                |          Dim Dir As CATIAHybridShapeDirection
                |          Set Dir=Translate.Direction

        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_translate.Direction)

    @direction.setter
    def direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_translate.Direction = direction.com_object

    @property
    def distance(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Distance() As Length (Read Only)
                | 
                |     Returns the translate distance.

        :rtype: Length
        """

        return Length(self.hybrid_shape_translate.Distance)

    @property
    def distance_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DistanceValue() As double
                | 
                |     Returns or sets the translate distance value.
                | 
                |     Example
                |         This example retrieves in DistVal the translation distance value for
                |         the Translate hybrid shape feature.
                | 
                |          Dim DistVal As double
                |          Set DistVal =Translate.DistanceValue

        :rtype: float
        """

        return self.hybrid_shape_translate.DistanceValue

    @distance_value.setter
    def distance_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_translate.DistanceValue = value

    @property
    def elem_to_translate(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ElemToTranslate() As Reference
                | 
                |     Returns or sets the element to translate.
                | 
                |     Example
                |         This example retrieves in Element the element to be translated for the
                |         Translate hybrid shape feature.
                | 
                |          Dim Element As Reference
                |          Set Element=Translate.ElemToTranslate

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_translate.ElemToTranslate)

    @elem_to_translate.setter
    def elem_to_translate(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_translate.ElemToTranslate = reference_element.com_object

    @property
    def first_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstPoint() As Reference
                | 
                |     Returns or sets the first point defining the translation.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_translate.FirstPoint)

    @first_point.setter
    def first_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_translate.FirstPoint = reference_point.com_object

    @property
    def ref_axis_system(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RefAxisSystem() As Reference
                | 
                |     Returns or Sets the reference Axis System for Translate
                |     feature.
                |     This data is not mandatory, if element is null, the absolute axis system is
                |     taken.
                |     When an element is given, X, Y and Z are considered in this Axis system.
                |     
                | Example
                | :
                |     This example retrieves in oRefAxis the reference Axis System for Translate
                |     feature.
                | 
                |      Dim oRefAxis As CATIAReference
                |      Set oRefAxis  = Translate.RefAxisSystem

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_translate.RefAxisSystem)

    @ref_axis_system.setter
    def ref_axis_system(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_translate.RefAxisSystem = reference_axis.com_object

    @property
    def second_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondPoint() As Reference
                | 
                |     Returns or sets the second point defining the translation.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_translate.SecondPoint)

    @second_point.setter
    def second_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_translate.SecondPoint = reference_point.com_object

    @property
    def vector_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property VectorType() As long
                | 
                |     Returns or sets the way the translation vector is defined.
                | 
                |         0= Direction + distance
                |         1= point + points
                |         2= coordinates
                |         3= Unknown type

        :rtype: int
        """

        return self.hybrid_shape_translate.VectorType

    @vector_type.setter
    def vector_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_translate.VectorType = value

    @property
    def volume_result(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property VolumeResult() As boolean
                | 
                |     Returns or sets the volume result.
                |     Legal values: True if the result of translation is required as volume
                |     (option is effective only in case of volumes,requires GSO License) and False if
                |     it is needed as surface .
                | 
                |     Example:
                | 
                |           This example sets that the result of
                |          the hybShpTranslate hybrid shape translate is volume.
                |          
                | 
                |          hybShpTranslate.VolumeResult = True

        :rtype: bool
        """

        return self.hybrid_shape_translate.VolumeResult

    @volume_result.setter
    def volume_result(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_translate.VolumeResult = value

    def get_creation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetCreationMode() As long
                | 
                |     Gets the creation mode.
                |     Legal values:
                | 
                |     0
                |         CATGSMTransfoModeUnset. Default behavior: creation mode by default for
                |         all features, modification mode for axis system
                |     1
                |         CATGSMTransfoModeCreation. Creation mode. 
                |     2
                |         CATGSMTransfoModeModification. Modification mode. 
                | 
                | Example:
                |     This example retrieves in oCreation the creation mode for the
                |     hybShpTranslate hybrid shape feature.
                | 
                |      oCreation = hybShpTranslate.GetCreationMode

        :rtype: int
        """
        return self.hybrid_shape_translate.GetCreationMode()

    def set_creation_mode(self, i_creation: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetCreationMode(boolean iCreation)
                | 
                |     Sets the creation mode(creation or modification).
                |     Legal values: True if the result is a creation feature and False if the
                |     result is a modification feature.
                | 
                |     Example:
                | 
                |           This example sets that the mode of
                |          the hybShpTranslate hybrid shape translate to
                |          creation
                |          
                | 
                |          hybShpTranslate.SetCreationMode True

        :param bool i_creation:
        :rtype: None
        """
        return self.hybrid_shape_translate.SetCreationMode(i_creation)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_creation_mode'
        # # vba_code = """
        # # Public Function set_creation_mode(hybrid_shape_translate)
        # #     Dim iCreation (2)
        # #     hybrid_shape_translate.SetCreationMode iCreation
        # #     set_creation_mode = iCreation
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeTranslate(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.kinematics_interfaces.mechanism import Mechanism
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class Dressup(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Dressup
                | 
                | Interface to access the Dressup object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dressup = com_object

    @property
    def context(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Context() As Product (Read Only)
                | 
                |     Returns the context product on which the mechanism is defined. This
                |     property is read only.
                | 
                |     Returns:
                |         The dressup mechanism's context 
                |     Example:
                |         This example sets in MecaContext the context product of
                |         MyDressup.
                | 
                |             Dim MecaContext As Product
                |             Set MecaContext = MyDressup.Context

        :rtype: Product
        """

        return Product(self.dressup.Context)

    @property
    def mechanism(self) -> Mechanism:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Mechanism() As Mechanism (Read Only)
                | 
                |     Returns the mechanism on which a dressup is applied. This property is read
                |     only.
                | 
                |     Returns:
                |         The dressup's mechanism 
                |     Example:
                |         This example sets in Meca the mechanism of MyDressup.
                | 
                |           Dim Meca As Mechanism
                |           Set Meca = MyDressup.Mechanism

        :rtype: Mechanism
        """

        return Mechanism(self.dressup.Mechanism)

    def attach(self, i_link: Product, i_attached_prod: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Attach(Product iLink,
                | Product iAttachedProd)
                | 
                |     Attaches a given product to a link of the mechanism pointed by the
                |     dressup.
                | 
                |     Parameters:
                | 
                |         iLink
                |             The link (Product) on which the attachment should be done. It
                |             should be a product that belongs to the mechanism pointed by the dressup,
                |             otherwise the method will fail. 
                |         iAttachedProd
                |             The Product that will be attached to the link. This product should
                |             not be a product that is already attached by another link, otherwise the method
                |             will fail. 
                | 
                |     Returns:
                |         Nothing 
                |     Example:
                |         This example attaches inside MyDressup, Link1 as mechanism's part to
                |         Product1.
                | 
                |             Dim Link1 As Product
                |             Dim Product1 As Product
                |             ...
                |             MyDressup.Attach(Link1,Product1)

        :param Product i_link:
        :param Product i_attached_prod:
        :rtype: None
        """
        return self.dressup.Attach(i_link.com_object, i_attached_prod.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'attach'
        # # vba_code = """
        # # Public Function attach(dressup)
        # #     Dim iLink (2)
        # #     dressup.Attach iLink
        # #     attach = iLink
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def detach(self, i_attached_prod: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Detach(Product iAttachedProd)
                | 
                |     Detaches an attached product from its link.
                | 
                |     Parameters:
                | 
                |         iAttachedProd
                |             The Product that will be detached. It should be a product that is
                |             currently attached in the dressup, otherwise the method will fail.
                |             
                | 
                |     Returns:
                |         Nothing 
                |     Example:
                |         This example detaches Product1 previously attached to a mechanism's
                |         part inside MyDressup.
                | 
                |             Dim Product1 As Product
                |             ...
                |             MyDressup.Detach(Product1)

        :param Product i_attached_prod:
        :rtype: None
        """
        return self.dressup.Detach(i_attached_prod.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'detach'
        # # vba_code = """
        # # Public Function detach(dressup)
        # #     Dim iAttachedProd (2)
        # #     dressup.Detach iAttachedProd
        # #     detach = iAttachedProd
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_attached(self, i_link: Product) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListAttached(Product iLink) As CATSafeArrayVariant
                | 
                |     Returns the list of products attached to a given link.
                | 
                |     Parameters:
                | 
                |         iLink
                |             The Product on which the returned product list is attached to.
                |             
                | 
                |     Returns:
                |         The Product list that is attached to iLink. 
                |     Example:
                |         The following example loops for all the products attached to
                |         Link1.
                | 
                |             Dim ListAttached1 as Product
                |             ListAttached1 = MyDressup.ListAttached(Link1)
                |             Dim Maxi as Integer
                |             Set Maxi = ubound(ListAttached1)
                |             Dim Prod_i as Product
                |             For i = 0  To  Maxi
                |                Set Prod_i = ListAttached1(i)
                |                ..
                |             Next

        :param Product i_link:
        :rtype: tuple
        """
        return self.dressup.ListAttached(i_link.com_object)

    def __repr__(self):
        return f'Dressup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.general_statistics_setting_att import GeneralStatisticsSettingAtt


class PcsStatisticsSettingAtt(GeneralStatisticsSettingAtt):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         System.GeneralStatisticsSettingAtt
                |                             PCSStatisticsSettingAtt
                | 
                | Interface for PCS statistic Controller
                | Role: the PCS statistics controller manages the values of all or only a part of
                | the attributes available for the thematic.
                | 
                | For the definitions of methods and variables common to every thematic, see the
                | GeneralStatisticsSettingAtt
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pcs_statistics_setting_att = com_object

    @property
    def mem_use(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property MemUse() As boolean
                | 
                |     Returns or sets the state ot the memory field.
                |     Role: Returns or sets the state ot the workbench name
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.pcs_statistics_setting_att.MemUse

    @mem_use.setter
    def mem_use(self, value):
        """
        :param bool value:
        """

        self.pcs_statistics_setting_att.MemUse = value

    def __repr__(self):
        return f'PcsStatisticsSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPResource(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspResource
                | 
                | Represents the PspResource.
                | Role: It is used to get application resources.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_resource = com_object

    def get_resource_path(self, i_resource_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetResourcePath(CATBSTR iResourceName) As CATBSTR
                | 
                |     Returns the path value defined for a resource.
                | 
                |     Parameters:
                | 
                |         iResourceName
                |             Resource Name 
                | 
                |     Returns:
                |         Resource Path
                |
                |     Example:
                |
                |          Dim objThisIntf As PspResource
                |          Dim strResourcePath As String
                |          Dim iResourceName As String 
                |           ...
                |          strResourcePath = objThisIntf.GetResourcePath (iResourceName)

        :param str i_resource_name:
        :rtype: str
        """
        return self.psp_resource.GetResourcePath(i_resource_name)

    def get_resource_value(self, i_resource_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetResourceValue(CATBSTR iResourceName) As CATBSTR
                | 
                |     Returns the value defined for a resource.
                | 
                |     Parameters:
                | 
                |         iResourceName
                |             Resource Name 
                | 
                |     Returns:
                |         Resource Value
                |
                |     Example:
                |
                |          Dim objThisIntf As PspResource
                |          Dim strResourceVal As String
                |           ...
                |          strResourceVal = objThisIntf.GetResourceValue (iResourceName)

        :param str i_resource_name:
        :rtype: str
        """
        return self.psp_resource.GetResourceValue(i_resource_name)

    def __repr__(self):
        return f'PSPResource(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dmaps_interfaces.resource import Resource
from pycatia.dnb_fastener_interfaces.fastener import Fastener
from pycatia.dnb_fastener_interfaces.fastener_set import FastenerSet
from pycatia.system_interfaces.any_object import AnyObject


class DnbFastenerItemServices(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBFastenerItemServices

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dnb_fastener_item_services = com_object

    def assign_fastener_to_process(self, i_fastener: Fastener, i_process: Activity, e_status: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AssignFastenerToProcess(Fastener iFastener,
                | Activity iProcess,
                | DNBAssignStatus eStatus)
                | 
                |     Assigns a specified DELMIAFastener to a specified Activity and return the
                |     status of the action. Activity can be a TSA (for Resource) as well. *
                |     
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerItemServices") Dim AssignStatus As EnumParam myObject.AssignFastenerToProcess MyFastener,MyActivity,AssignStatus MsgBox AssignStatus

        :param Fastener i_fastener:
        :param Activity i_process:
        :param int e_status: enum dnb_assign_status
        :rtype: None
        """
        return self.dnb_fastener_item_services.AssignFastenerToProcess(i_fastener.com_object, i_process.com_object,
                                                                       e_status)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'assign_fastener_to_process'
        # # vba_code = """
        # # Public Function assign_fastener_to_process(dnb_fastener_item_services)
        # #     Dim iFastener (2)
        # #     dnb_fastener_item_services.AssignFastenerToProcess iFastener
        # #     assign_fastener_to_process = iFastener
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def assign_fastener_to_resource(self, i_fastener: Fastener, i_resource: Resource, e_status: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AssignFastenerToResource(Fastener iFastener,
                | Resource iResource,
                | DNBAssignStatus eStatus)
                | 
                |     Assigns a specified DELMIAFastener to a specified Resource and return the
                |     status of the action. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerItemServices") Dim AssignStatus As EnumParam myObject.AssignFastenerToResource MyFastener,MyResource,AssignStatus MsgBox AssignStatus

        :param Fastener i_fastener:
        :param Resource i_resource:
        :param int e_status: enum dnb_assign_status
        :rtype: None
        """
        return self.dnb_fastener_item_services.AssignFastenerToResource(
            i_fastener.com_object,
            i_resource.com_object,
            e_status
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'assign_fastener_to_resource'
        # # vba_code = """
        # # Public Function assign_fastener_to_resource(dnb_fastener_item_services)
        # #     Dim iFastener (2)
        # #     dnb_fastener_item_services.AssignFastenerToResource iFastener
        # #     assign_fastener_to_resource = iFastener
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_fasteners(self, i_products: tuple, b_joining_fasteners: bool, o_fastener_array: tuple) -> list:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetFasteners(CATSafeArrayVariant iProducts,
                | boolean bJoiningFasteners,
                | CATSafeArrayVariant oFastenerArray)
                | 
                |     Gets all the Fasteners on the products.
                | 
                |     Parameters:
                | 
                |         bJoiningFasteners
                |             Decides whether only the fastener joining the products will be
                |             returned(true) or all the fasteners on all the products(false)
                |             
                | 
                |     Example:
                |         Set myObject = CATIA.GetItem("DNBFastenerItemServices")
                |         Dim MyNum
                |         MyNum = myObject.GetNumberOfFasteners (MyProductArray, false)
                |         Dim MyFastenerList() As AnyObject
                |         ReDim MyFastenerList(MyNum) myObject.GetFasteners MyProductList,false,MyFastenerList

        :param tuple i_products:
        :param bool b_joining_fasteners:
        :param tuple o_fastener_array:
        :rtype: AnyObject
        """
        return self.dnb_fastener_item_services.GetFasteners(i_products, b_joining_fasteners, o_fastener_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_fasteners'
        # # vba_code = """
        # # Public Function get_fasteners(dnb_fastener_item_services)
        # #     Dim iProducts (2)
        # #     dnb_fastener_item_services.GetFasteners iProducts
        # #     get_fasteners = iProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_fasteners_from_process(self, i_operation: Activity, i_fasteners: FastenerSet) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetFastenersFromProcess(Activity iOperation,
                | FastenerSet iFasteners)
                | 
                |     Gets all the DELMIAFasteners assigned to the Activity. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerItemServices")
                |     Dim FastenerLot As FatenerSet
                |     myObject.GetFastenersFromProcess MyActivity,FastenerLot

        :param Activity i_operation:
        :param FastenerSet i_fasteners:
        :rtype: None
        """
        return self.dnb_fastener_item_services.GetFastenersFromProcess(i_operation.com_object, i_fasteners.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_fasteners_from_process'
        # # vba_code = """
        # # Public Function get_fasteners_from_process(dnb_fastener_item_services)
        # #     Dim iOperation (2)
        # #     dnb_fastener_item_services.GetFastenersFromProcess iOperation
        # #     get_fasteners_from_process = iOperation
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_fasteners_from_resource(self, i_resource: Resource, i_fasteners: FastenerSet) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetFastenersFromResource(Resource iResource,
                | FastenerSet iFasteners)
                | 
                |     Gets all the DELMIAFasteners assigned to the Resource. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerItemServices")
                |     Dim FastenerLot As FatenerSet
                |     myObject.GetFastenersFromProcess MyResource,FastenerLot

        :param Resource i_resource:
        :param FastenerSet i_fasteners:
        :rtype: None
        """
        return self.dnb_fastener_item_services.GetFastenersFromResource(i_resource.com_object, i_fasteners.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_fasteners_from_resource'
        # # vba_code = """
        # # Public Function get_fasteners_from_resource(dnb_fastener_item_services)
        # #     Dim iResource (2)
        # #     dnb_fastener_item_services.GetFastenersFromResource iResource
        # #     get_fasteners_from_resource = iResource
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_number_of_fasteners(self, i_products: tuple, b_joining_fasteners: bool) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfFasteners(CATSafeArrayVariant iProducts,
                | boolean bJoiningFasteners) As long
                | 
                |     Gets the number of Fasteners on the products.
                | 
                |     Parameters:
                | 
                |         bJoiningFasteners
                |             Decides whether only the fastener joining the products will be
                |             returned(true) or all the fasteners on all the products(false)
                |             
                | 
                |     Example:
                |         Set myObject = CATIA.GetItem("DNBFastenerItemServices")
                |         Dim MyNum
                |         MyNum = myObject.GetNumberOfFasteners (MyProductArray, false)

        :param tuple i_products:
        :param bool b_joining_fasteners:
        :rtype: int
        """
        return self.dnb_fastener_item_services.GetNumberOfFasteners(i_products, b_joining_fasteners)

    def remove_fastener_from_process(self, i_fastener: Fastener, i_process: Activity) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveFastenerFromProcess(Fastener iFastener,
                | Activity iProcess)
                | 
                |     Unassigns a specified DELMIAFastener from a specified Activity. *
                |     
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerItemServices")
                |     myObject.RemoveFastenerFromProcess MyFastener,MyActivity

        :param Fastener i_fastener:
        :param Activity i_process:
        :rtype: None
        """
        return self.dnb_fastener_item_services.RemoveFastenerFromProcess(i_fastener.com_object, i_process.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_fastener_from_process'
        # # vba_code = """
        # # Public Function remove_fastener_from_process(dnb_fastener_item_services)
        # #     Dim iFastener (2)
        # #     dnb_fastener_item_services.RemoveFastenerFromProcess iFastener
        # #     remove_fastener_from_process = iFastener
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_fastener_from_resource(self, i_fastener: Fastener, i_resource: Resource) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveFastenerFromResource(Fastener iFastener,
                | Resource iResource)
                | 
                |     Unassigns a specified DELMIAFastener from a specified Resource. *
                |     
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerItemServices")
                |     myObject.RemoveFastenerFromResource MyFastener,MyResource

        :param Fastener i_fastener:
        :param Resource i_resource:
        :rtype: None
        """
        return self.dnb_fastener_item_services.RemoveFastenerFromResource(i_fastener.com_object, i_resource.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_fastener_from_resource'
        # # vba_code = """
        # # Public Function remove_fastener_from_resource(dnb_fastener_item_services)
        # #     Dim iFastener (2)
        # #     dnb_fastener_item_services.RemoveFastenerFromResource iFastener
        # #     remove_fastener_from_resource = iFastener
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DnbFastenerItemServices(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.system_interfaces.any_object import AnyObject


class Limit(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Limit
                | 
                | Represents the limit of a prism or a hole shape.
                | 
                | See also:
                |     Prism, Hole
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.limit = com_object

    @property
    def dimension(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Dimension() As Length (Read Only)
                | 
                |     Returns or sets the limit dimension. This property is valid for the offset
                |     limit mode only, that is when CatLimitMode is set to catOffsetLimit .

        :rtype: Length
        """

        return Length(self.limit.Dimension)

    @property
    def limit_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LimitMode() As CatLimitMode
                | 
                |     Returns or sets the limit mode.

        :return: enum cat_limit_mode
        :rtype: int
        """

        return self.limit.LimitMode

    @limit_mode.setter
    def limit_mode(self, value: int):
        """
        :param int value: enum cat_limit_mode
        """

        self.limit.LimitMode = value

    @property
    def limiting_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LimitingElement() As Reference
                | 
                |     Returns or sets the limiting element. This property is valid when the
                |     limiting object is a surface or a plane, that is when CatLimitMode is set to
                |     catUpToSurfaceLimit and catUpToPlaneLimit.
                |     To set the property, you can use the following Boundary object: Face.

        :rtype: Reference
        """

        return Reference(self.limit.LimitingElement)

    @limiting_element.setter
    def limiting_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.limit.LimitingElement = value.com_object

    def __repr__(self):
        return f'Limit(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class AttachmentCont(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AttachmentCont
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement DNBIABasicDevice are ...
                | 
                | Do not use the DNBIAMRLDocAttachments interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.attachment_cont = com_object

    def get_attachment_factory(self, o_attach_factory: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAttachmentFactory(CATBaseDispatch oAttachFactory)
                | 
                |     Get the AttachmentFactory for the current document
                | 
                |     Parameters:
                | 
                |         oAttachFactory
                |             This output parameter contains the AttachmentFactory for the
                |             current document. 
                | 
                |     Returns:
                |         An HRESULT

        :param AnyObject o_attach_factory:
        :rtype: None
        """
        return self.attachment_cont.GetAttachmentFactory(o_attach_factory.com_object)

    def get_listof_attachments(self, o_attach_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListofAttachments(CATSafeArrayVariant oAttachList)
                | 
                |     Get list of attachments from the Attachment Container
                | 
                |     Parameters:
                | 
                |         oAttachList
                |             This output parameter contains the list of attachments in a
                |             document. 
                | 
                |     Returns:
                |         An HRESULT

        :param tuple o_attach_list:
        :rtype: None
        """
        return self.attachment_cont.GetListofAttachments(o_attach_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_listof_attachments'
        # # vba_code = """
        # # Public Function get_listof_attachments(attachment_cont)
        # #     Dim oAttachList (2)
        # #     attachment_cont.GetListofAttachments oAttachList
        # #     get_listof_attachments = oAttachList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AttachmentCont(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_property import ABQProperty
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQProperties(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQProperties
                | 
                | The collection of Abaqus property objects (ABQProperty) attached to
                | an
                | ABQAnalysisModel object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQProperty)
        self.abq_properties = com_object

    def add(self, i_property_type: str) -> ABQProperty:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iPropertyType) As ABQProperty
                | 
                |     Creates a new Abaqus Property and adds it to the collection of Abaqus
                |     Properties.
                | 
                |     Parameters:
                | 
                |         iPropertyType
                |             The type of the Property to create.
                | 
                |             Legal values:
                | 
                |             "ABQTabularAmplitude"
                |             "ABQSmoothStepAmplitude"
                |             "ABQMechConnBehavior"
                |             "ABQThermalConnBehavior"
                |             "ABQPreTensionProperty"
                |             "ABQGasketProperty"
                | 
                |     Returns:
                |         oProperty The Abaqus Property object that was created.
                |         
                |     Example:
                |         The following example creates a Tabular Amplitude Property in the
                |         ABQProperties collection:
                | 
                |          Dim abaqusproperties As ABQPropertiess
                |          Dim abqtabularAmpl As ABQTabularAmplitude
                |          Set abqtabularAmpl =  abaqusproperties.Add("ABQTabularAmplitude")

        :param str i_property_type:
        :rtype: ABQProperty
        """
        return ABQProperty(self.abq_properties.Add(i_property_type))

    def item(self, i_index: cat_variant) -> ABQProperty:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQProperty
                | 
                |     Returns an Abaqus property using its index or its name from the
                |     ABQProperties collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus property to retrieve from the
                |             collection of Abaqus properties. If the index is a number, it specifies the
                |             rank of the Abaqus property in the collection. The index of the first Abaqus
                |             property in the collection is 1, and the index of the last property is Count.
                |             If the index is a string, it specifies the name you assigned to the property
                |             using the CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQProperty.

        :param cat_variant i_index:
        :rtype: ABQProperty
        """
        return ABQProperty(self.abq_properties.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a Abaqus property using its index or its name from the property
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus property to retrieve from the
                |             collection of Abaqus Properties. If the index is a number, it specifies the
                |             rank of the Abaqus property in the collection. The index of the first Abaqus
                |             property in the collection is 1, and the index of the last property is Count.
                |             If the index is a string, it specifies the name you assigned to the property
                |             using the CATIABase::Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_properties.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_properties)
        # #     Dim iIndex (2)
        # #     abq_properties.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQProperties(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.functional_action import FunctionalAction
from pycatia.funct_system_interfaces.functional_position import FunctionalPosition
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class FunctionalActions(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FunctionalActions
                | 
                | The interface to access a collection of FunctionalActions.
    
    """

    def __init__(self, com_object, child_object=FunctionalAction):
        super().__init__(com_object, child_object=FunctionalAction)
        self.functional_actions = com_object
        self.child_object = child_object

    def create(self, i_name: str, i_from: FunctionalPosition, i_to: FunctionalPosition) -> FunctionalAction:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Create(CATBSTR iName,
                | FunctionalPosition iFrom,
                | FunctionalPosition iTo) As FunctionalAction
                | 
                |     Create a FunctionalAction.

        :param str i_name:
        :param FunctionalPosition i_from:
        :param FunctionalPosition i_to:
        :rtype: FunctionalAction
        """
        return FunctionalAction(self.functional_actions.Create(i_name, i_from.com_object, i_to.com_object))

    def delete(self, i_action: FunctionalAction) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Delete(FunctionalAction iAction)
                | 
                |     Delete a FunctionalAction.

        :param FunctionalAction i_action:
        :rtype: None
        """
        return self.functional_actions.Delete(i_action.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete'
        # # vba_code = """
        # # Public Function delete(functional_actions)
        # #     Dim iAction (2)
        # #     functional_actions.Delete iAction
        # #     delete = iAction
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def elem(self, i_index: cat_variant) -> FunctionalAction:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Elem(CATVariant iIndex) As FunctionalAction
                | 
                |     Returns an action using its index or its name from the actions
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the action to retrieve from the collection
                |             of actions. As a numerics, this index is the rank of the action in the
                |             collection. The index of the first action in the collection is 1, and the index
                |             of the last action is Count. As a string, it is the name you assigned to the
                |             action using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved action 
                |     Example:
                |         This example retrieves in Act1 the fifth action in the collection and
                |         in Act2 the action named Moves.
                | 
                |          Dim Act1 As FunctionalAction
                |          Set Act1 = Desc.Action(5)
                |          Dim Act2 As FunctionalAction
                |          Set Act2 = Desc.Action("Moves")

        :param cat_variant i_index:
        :rtype: FunctionalAction
        """
        return FunctionalAction(self.functional_actions.Elem(i_index))

    def __repr__(self):
        return f'FunctionalActions(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_application import PSPApplication
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class PSPWorkbench(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspWorkbench
                | 
                | Represents the PspWorkbench.
                | Role: To manage application and Psp interface handlers. From this object all
                | the queries for lists of Distributive system (PSP) objects can be made.
                | Furthermore, all the interface handles can be obtained through this
                | interface.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_workbench = com_object

    def export_properties(self, i_document_to_export_from: Document, i_xml_output_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportProperties(Document iDocumentToExportFrom,
                | CATBSTR iXMLOutputFileName)
                | 
                |     This method extracts property values of the current document to an output
                |     XML file. The format is determined by CATIA PlantShip XML-DTD
                |     file.
                | 
                |     Parameters:
                | 
                |         iDocumentToExportFrom
                |             Documennt to export from 
                |         iXMLOutputFileName
                |             The file name to output the data to.
                |
                |     Example:
                |
                |          Dim objPspWorkbench As PspWorkbench  
                |          Dim objCATIAV5CurDocument As Document
                |          Dim iXMLOutputFileName As String
                |          Set objCATIAV5CurDocument = CATIA.ActiveDocument  
                |          Set objProductRoot = objCATIAV5CurDocument.Product
                |          Set objPspWorkbench = objProductRoot.GetTechnologicalObject ("PspWorkbench")
                |          ..
                |          objThisIntf.ExportProperties objCATIAV5CurDocument,
                |          iXMLOutputFileName

        :param Document i_document_to_export_from:
        :param str i_xml_output_file_name:
        :rtype: None
        """
        return self.psp_workbench.ExportProperties(i_document_to_export_from.com_object, i_xml_output_file_name)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_properties'
        # # vba_code = """
        # # Public Function export_properties(psp_workbench)
        # #     Dim iDocumentToExportFrom (2)
        # #     psp_workbench.ExportProperties iDocumentToExportFrom
        # #     export_properties = iDocumentToExportFrom
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_application(self, i_application_id: int) -> PSPApplication:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetApplication(CatPspIDLApplicationID iApplicationID) As
                | PspApplication
                | 
                |     Returns the PspApplication associated with the input
                |     ApplicationID.
                | 
                |     Parameters:
                | 
                |         CatPspIDLApplicationID
                |             Application ID to get. 
                |         oApplication
                |             PspApplication handle found. 
                | 
                |     Example:
                |
                |          Dim objPspWorkbench As PspWorkbench
                |          Dim objArg1 As CatPspIDLApplicationID
                |          Dim objArg2 As PspApplication
                |          objArg1 = catPspIDLCATPiping
                |          Set objArg2 = objPspWorkbench.GetApplication (objArg1)

        :param int i_application_id: enum cat_psp_idl_application_id
        :rtype: PSPApplication
        """
        return PSPApplication(self.psp_workbench.GetApplication(i_application_id))

    def get_interface(self, i_interface_name: str, i_object: AnyObject) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetInterface(CATBSTR iInterfaceName,
                | AnyObject iObject) As AnyObject
                | 
                |     Returns specific interface handle on a given object.
                | 
                |     Parameters:
                | 
                |         iInterfaceName
                |             interface name to search for ("CATIAxxxx") 
                |         iObject
                |             The object to search for the required interface. 
                | 
                |     Returns:
                |         Interface handle found
                |
                |     Example:
                | 
                |           This example illustrates how to get a specific interface handle from
                |           a given object. 
                |
                |          Dim objPspWorkbench As PspWorkbench
                |          Dim objPspApplication As PspApplication
                |          Dim objPspAppFactory As PspAppFactory
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objPspWorkbench = objProductRoot.GetTechnologicalObject ("PspWorkbench")
                |          Set objPspPipApplication = objPspWorkbench.GetApplication(catPspIDLCATPiping)
                | 
                |          Set objPspPipAppFactory = objPspWorkbench.GetInterface ("CATIAPspAppFactory",objPspPipApplication)

        :param str i_interface_name:
        :param AnyObject i_object:
        :rtype: AnyObject
        """
        return AnyObject(self.psp_workbench.GetInterface(i_interface_name, i_object.com_object))

    def __repr__(self):
        return f'PSPWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class LibTabSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         LibTabSettingAtt

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.lib_tab_setting_att = com_object

    def get_id_unique_setting(self, o_is_unique: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetIDUniqueSetting(long oIsUnique)
                | 
                |     Retrieves the option which enables to check ID uniqueness amongst sibling
                |     processes
                |     Role: Retrieves the option which enables to check ID uniqueness amongst
                |     sibling processes
                | 
                |     Parameters:
                | 
                |         oIsUnique
                |             Flag indicating whether the check should be enabled or not
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int o_is_unique:
        :rtype: None
        """
        return self.lib_tab_setting_att.GetIDUniqueSetting(o_is_unique)

    def get_id_unique_setting_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetIDUniqueSettingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the 'Unique Check'
                |     parameter.
                |     Role:Retrieves the state of the 'Unique Check' parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.lib_tab_setting_att.GetIDUniqueSettingInfo(io_admin_level, io_locked)

    def get_list_of_library_file_path(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetListOfLibraryFilePath() As CATSafeArrayVariant
                | 
                |     Retrieves the List of Libraries that are used in the Process
                |     document
                |     Role: Retrieves the List of Libraries that are used in the Process
                |     document
                | 
                |     Parameters:
                | 
                |         ioPath
                |             a CATSafeArrayVariant of CATBSTR that has the list of libraries
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: tuple
        """
        return self.lib_tab_setting_att.GetListOfLibraryFilePath()

    def get_list_of_library_file_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetListOfLibraryFilePathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves the information about the list of libraries path that are used in
                |     the Process document
                |     Role:Retrieves the information about the list of libraries path that are
                |     used in the Process document
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.lib_tab_setting_att.GetListOfLibraryFilePathInfo(io_admin_level, io_locked)

    def get_process_id_script(self, o_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetProcessIDScript(CATBSTR oPath)
                | 
                |     Retrieves the path of custom VB script to generate process
                |     ID
                |     Role: Retrieves the path of custom VB script to generate process
                |     ID
                | 
                |     Parameters:
                | 
                |         oPath
                |             The output path of the custom VB script 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str o_path:
        :rtype: None
        """
        return self.lib_tab_setting_att.GetProcessIDScript(o_path)

    def get_process_id_script_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProcessIDScriptInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves the information about the custom VB script path that are used in
                |     the Process document
                |     Role:Retrieves the information about the custom VB script path that are
                |     used in the Process document
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.lib_tab_setting_att.GetProcessIDScriptInfo(io_admin_level, io_locked)

    def put_list_of_library_file_path(self, i_path: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutListOfLibraryFilePath(CATSafeArrayVariant iPath)
                | 
                |     Sets a List of Libraries that are used in the Process
                |     document
                |     Role: Sets the List of Libraries that are used in the Process
                |     document
                | 
                |     Parameters:
                | 
                |         iPath
                |             a CATSafeArrayVariant of CATBSTR that has the list of libraries.
                |
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param tuple i_path:
        :rtype: None
        """
        return self.lib_tab_setting_att.PutListOfLibraryFilePath(i_path)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_list_of_library_file_path'
        # # vba_code = """
        # # Public Function put_list_of_library_file_path(lib_tab_setting_att)
        # #     Dim iPath (2)
        # #     lib_tab_setting_att.PutListOfLibraryFilePath iPath
        # #     put_list_of_library_file_path = iPath
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_id_unique_setting(self, is_unique: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetIDUniqueSetting(long isUnique)
                | 
                |     Sets the option which enables to check ID uniqueness amongst sibling
                |     processes
                |     Role: Sets the option which enables to check ID uniqueness amongst sibling
                |     processes
                | 
                |     Parameters:
                | 
                |         isUnique
                |             Sets the option to enable uniqueness check or not 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int is_unique:
        :rtype: None
        """
        return self.lib_tab_setting_att.SetIDUniqueSetting(is_unique)

    def set_id_unique_setting_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetIDUniqueSettingLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Unique Check" parameter.
                |     Role: Locks or unlocks the 'Unique Check' parameter if the operation is
                |     allowed in the current administrated environment. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.lib_tab_setting_att.SetIDUniqueSettingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_id_unique_setting_lock'
        # # vba_code = """
        # # Public Function set_id_unique_setting_lock(lib_tab_setting_att)
        # #     Dim iLocked (2)
        # #     lib_tab_setting_att.SetIDUniqueSettingLock iLocked
        # #     set_id_unique_setting_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_list_of_library_file_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetListOfLibraryFilePathLock(boolean iLocked)
                | 
                |     Locks or unlocks the list of libraries to be used
                |     Role:Locks or unlocks the "list of libraries" parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.lib_tab_setting_att.SetListOfLibraryFilePathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_list_of_library_file_path_lock'
        # # vba_code = """
        # # Public Function set_list_of_library_file_path_lock(lib_tab_setting_att)
        # #     Dim iLocked (2)
        # #     lib_tab_setting_att.SetListOfLibraryFilePathLock iLocked
        # #     set_list_of_library_file_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_process_id_script(self, i_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProcessIDScript(CATBSTR iPath)
                | 
                |     Sets the path of custom VB script to generate process ID
                |     Role: Sets the path of custom VB script to generate process
                |     ID
                | 
                |     Parameters:
                | 
                |         iPath
                |             Path of the custom VB script to be set 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_path:
        :rtype: None
        """
        return self.lib_tab_setting_att.SetProcessIDScript(i_path)

    def set_process_id_script_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProcessIDScriptLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Custom VB Script" parameter.
                |     Role: Locks or unlocks the 'Custom VB Script' parameter if the operation is
                |     allowed in the current administrated environment. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             1 : to lock the parameter.
                |             0: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.lib_tab_setting_att.SetProcessIDScriptLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_process_id_script_lock'
        # # vba_code = """
        # # Public Function set_process_id_script_lock(lib_tab_setting_att)
        # #     Dim iLocked (2)
        # #     lib_tab_setting_att.SetProcessIDScriptLock iLocked
        # #     set_process_id_script_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'LibTabSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.drafting_2dL_interfaces.layout_2d_views import Layout2DViews
from pycatia.drafting_interfaces.drawing_page_setup import DrawingPageSetup
from pycatia.drafting_interfaces.print_area import PrintArea
from pycatia.system_interfaces.any_object import AnyObject


class Layout2DSheet(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Layout2DSheet
                | 
                | The interface to access a Layout2D Sheet.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.layout_2d_sheet = com_object

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Orientation() As CatPaperOrientation
                | 
                |     Returns or sets the paper orientation.
                | 
                |     Example:
                |         This example sets the paper orientation for the MySheet Layout2D sheet
                |         to catPaperLandscape.
                | 
                |          MySheet.Orientation = catPaperLandscape

        :return: enum cat_paper_orientation
        :rtype: int
        """

        return self.layout_2d_sheet.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value: enum cat_paper_orientation
        """

        self.layout_2d_sheet.Orientation = value

    @property
    def page_setup(self) -> DrawingPageSetup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PageSetup() As DrawingPageSetup (Read Only)
                | 
                |     Returns the page setup.
                | 
                |     Example:
                |         This example returns the page setup for the MySheet Layout2D
                |         sheet.
                | 
                |          Dim MySheetPageSetup As DrawingPageSetup
                |          Set MySheetPageSetup = MySheet.PageSetup

        :rtype: DrawingPageSetup
        """

        return DrawingPageSetup(self.layout_2d_sheet.PageSetup)

    @property
    def paper_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PaperHeight() As double
                | 
                |     Gets or Sets the paper width of the layout sheet.
                | 
                |     Parameters:
                | 
                |         oPaperHeight
                | 
                |             Example:
                |                 This example get the height of the
                |                 Layout2DSheet1.
                | 
                |                  Layout2DSheet1.GetPaperHeight oPaperHeight

        :rtype: float
        """

        return self.layout_2d_sheet.PaperHeight

    @paper_height.setter
    def paper_height(self, value: float):
        """
        :param float value:
        """

        self.layout_2d_sheet.PaperHeight = value

    @property
    def paper_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PaperName() As CATBSTR
                | 
                |     Returns or sets the paper format name.
                | 
                |     Example:
                |         This example sets the paper format name for the MySheet Layout2D sheet
                |         to DSFormat1.
                | 
                |          MySheet.PaperName = DSFormat1

        :rtype: str
        """

        return self.layout_2d_sheet.PaperName

    @paper_name.setter
    def paper_name(self, value: str):
        """
        :param str value:
        """

        self.layout_2d_sheet.PaperName = value

    @property
    def paper_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PaperSize() As CatPaperSize
                | 
                |     Returns or sets the paper size.
                | 
                |     Example:
                |         This example sets the page size for the MySheet Layout2D sheet to
                |         catPaperA4.
                | 
                |          MySheet.PaperSize = catPaperA4

        :return: enum cat_paper_size
        :rtype: int
        """

        return self.layout_2d_sheet.PaperSize

    @paper_size.setter
    def paper_size(self, value: int):
        """
        :param int value: enum cat_paper_size
        """

        self.layout_2d_sheet.PaperSize = value

    @property
    def paper_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PaperWidth() As double
                | 
                |     Gets or Sets the paper width of the layout sheet.
                | 
                |     Parameters:
                | 
                |         oPaperWidth
                | 
                |             Example:
                |                 This example get the width of the Sheet1.
                | 
                |                  Sheet1.GetPaperWidth oPaperWidth

        :rtype: float
        """

        return self.layout_2d_sheet.PaperWidth

    @paper_width.setter
    def paper_width(self, value: float):
        """
        :param float value:
        """

        self.layout_2d_sheet.PaperWidth = value

    @property
    def print_area(self) -> PrintArea:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PrintArea() As PrintArea (Read Only)
                | 
                |     Returns the print area definition object.
                | 
                |     Example:
                |         This example returns the print area for the MySheet Layout2D sheet
                |         2DL.
                | 
                |          Dim MyPrintArea As PrintArea
                |          Set MyPrintArea = MySheet.PrintArea

        :rtype: PrintArea
        """

        return PrintArea(self.layout_2d_sheet.PrintArea)

    @property
    def projection_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ProjectionMethod() As CatSheetProjectionMethod
                | 
                |     Returns or sets the sheet projection mode .
                | 
                |     Example:
                |         This example sets the projection mode of the MySheet Layout2D sheet to
                |         catFirstAngle.
                | 
                |          MySheet.ProjectionMethod = catFirstAngle

        :return: enum cat_sheet_projection_method
        :rtype: int
        """

        return self.layout_2d_sheet.ProjectionMethod

    @projection_method.setter
    def projection_method(self, value: int):
        """
        :param int value: enum cat_sheet_projection_method
        """

        self.layout_2d_sheet.ProjectionMethod = value

    @property
    def sheet_scale(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SheetScale() As double
                | 
                |     Returns or sets the scale of the Layout2D sheet.
                | 
                |     Example:
                |         This example sets the scale of the MySheet Layout2D sheet to
                |         0.5.
                | 
                |          MySheet.SheetScale = 0.5

        :rtype: float
        """

        return self.layout_2d_sheet.SheetScale

    @sheet_scale.setter
    def sheet_scale(self, value: float):
        """
        :param float value:
        """

        self.layout_2d_sheet.SheetScale = value

    @property
    def views(self) -> Layout2DViews:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Views() As Layout2DViews (Read Only)
                | 
                |     Returns the Layout2D view collection of the Layout2D
                |     sheet.
                | 
                |     Example:
                |         This example retrieves in ViewCollection the collection of views 2DL of
                |         the MySheet Layout2D sheet.
                | 
                |          Dim ViewCollection As Layout2DViews
                |          Set ViewCollection = MySheet.Views.

        :rtype: Layout2DViews
        """

        return Layout2DViews(self.layout_2d_sheet.Views)

    @property
    def visu_in_3d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuIn3D() As CatVisuIn3DMode
                | 
                |     Set/Get the 3D visualization mode of the sheet in the 3D Viewer ie in the
                |     3D windows and in the background of each view in every 2D
                |     context.
                | 
                |     See also:
                |         CatVisuIn3DMode

        :return: enum cat_visu_in_3d_mode
        :rtype: int
        """

        return self.layout_2d_sheet.VisuIn3D

    @visu_in_3d.setter
    def visu_in_3d(self, value: int):
        """
        :param int value: enum cat_visu_in_3d_mode
        """

        self.layout_2d_sheet.VisuIn3D = value

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Activate()
                | 
                |     Activates the Layout2D sheet. Activating a Layout2D sheet means that this
                |     Layout2D sheet is the one on which the end user is now working. The window in
                |     the application's window collection which contains this Layout2D sheet becomes
                |     the active one.
                | 
                |     Example:
                |         This example activates the MySheet layout2dsheet.
                | 
                |          MySheet.Activate

        :rtype: None
        """
        return self.layout_2d_sheet.Activate()

    def is_detail(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsDetail() As boolean
                | 
                |     Checks whether the sheet is a detail sheet.
                |     TRUE if the sheet is a detail sheet.
                | 
                |     Example:
                |         This example checks whether MySheet is a detail sheet.
                | 
                |          IsDetail = MySheet.IsDetail

        :rtype: bool
        """
        return self.layout_2d_sheet.IsDetail()

    def print_out(self, i_rendering_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PrintOut(CatRenderingMode iRenderingMode)
                | 
                |     Prints the Layout2D sheet according to its page setup on the default
                |     printer.
                | 
                |     Parameters:
                | 
                |         iRenderingMode
                |             The rendering mode to use for the backgrounds of the views in the
                |             sheet.
                | 
                |             Example:
                |                 This example prints the Layout2DSheet1 on the default
                |                 printer.
                | 
                |                  Layout2DSheet1.PrintOut
                |                  catRenderShadingWithEdges

        :param int i_rendering_mode: enum cat_rendering_mode
        :rtype: None
        """
        return self.layout_2d_sheet.PrintOut(i_rendering_mode)

    def print_out_2(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PrintOut2()
                | 
                |     Prints the Layout2D sheet according to its page setup on the default
                |     printer. If a rendering mode has been stored on the 2D Layout, it is used
                |     during print process for the backgrounds. Otherwise, "Shading with edges"
                |     rendering mode is used.
                | 
                |     Example:
                |         This example prints the Layout2DSheet1 on the default
                |         printer.
                | 
                |          Layout2DSheet1.PrintOut2

        :rtype: None
        """
        return self.layout_2d_sheet.PrintOut2()

    def print_to_file(self, file_name: str, i_rendering_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PrintToFile(CATBSTR fileName,
                | CatRenderingMode iRenderingMode)
                | 
                |     Prints the Layout2D sheet according its page setup in a file instead of
                |     being sent to a printer.
                | 
                |     Parameters:
                | 
                |         fileName
                |             The full pathname of the file receiving the data. 
                |         iRenderingMode
                |             The rendering mode to use for the backgrounds of the views in the
                |             sheet. 
                | 
                |     Example:
                |         This example prints the Layout2DSheet1 in a file.
                | 
                |          Layout2DSheet1.PrintToFile
                |          "e:\\temp\\sheet1.prn",catRenderShadingWithEdges

        :param str file_name:
        :param int i_rendering_mode: enum cat_rendering_mode
        :rtype: None
        """
        return self.layout_2d_sheet.PrintToFile(file_name, i_rendering_mode)

    def print_to_file_2(self, file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PrintToFile2(CATBSTR fileName)
                | 
                |     Prints the Layout2D sheet according its page setup in a file instead of
                |     being sent to a printer. If a rendering mode has been stored on the 2D Layout,
                |     it is used during print process for the backgrounds. Otherwise, "Shading with
                |     edges" rendering mode is used.
                | 
                |     Parameters:
                | 
                |         fileName
                |             The full pathname of the file receiving the data. 
                | 
                |     Example:
                |         This example prints the Layout2DSheet1 in a file.
                | 
                |          Layout2DSheet1.PrintToFile2 "e:\\temp\\sheet1.prn"

        :param str file_name:
        :rtype: None
        """
        return self.layout_2d_sheet.PrintToFile2(file_name)

    def reorder_views(self, i_ordered_views: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub reorder_Views(CATSafeArrayVariant iOrderedViews)
                | 
                |     Changes the positions of the views in this sheet according to the given
                |     ordered list. iOrderedViews is the result of a permutation applied to the list
                |     of all the views of this sheet with the following constraint: the two first
                |     elements of the list must be respectively the sheet's mainview and background
                |     view.
                | 
                |     Example:
                |         This example modifies the views order of a sheet made of a mainview, a
                |         backgroundview and two user-created views. (user-created views are
                |         inverted).
                | 
                |          Set drw =  CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot")
                |          Set drwviewsorder = drwsheetsorder.Sheets.ActiveSheet
                |          Set drwviews = drwviewsorder.Views
                |          Set mainview = drwviews.item(1)
                |          Set backview = drwviews.item(2)
                |          Set view1 = drwviews.item(3)
                |          Set view2 = drwviews.item(4)
                |          newvieworder = Array(mainview, backview, view2, view1)
                |          drwviewsorder.reorder_Views(newvieworder)

        :param tuple i_ordered_views:
        :rtype: None
        """
        return self.layout_2d_sheet.reorder_Views(i_ordered_views)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reorder_views'
        # # vba_code = """
        # # Public Function reorder_views(layout2_d_sheet)
        # #     Dim iOrderedViews (2)
        # #     layout2_d_sheet.reorder_Views iOrderedViews
        # #     reorder_views = iOrderedViews
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Layout2DSheet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.workbench import Workbench
from pycatia.kinematics_interfaces.mechanisms import Mechanisms


class KinematicsWorkbench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         KinematicsWorkbench
                | 
                | Interface to access all Kinematics entities.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.kinematics_workbench = com_object

    @property
    def mechanisms(self) -> Mechanisms:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Mechanisms() As Mechanisms (Read Only)
                | 
                |     Returns the Mechanisms collection.
                | 
                |     Returns:
                |         The Mechanisms collection 
                |     Example:
                |         This example retrieves the Mechanisms collection of the active
                |         document.
                | 
                |             Dim TheKinWorkbench As Workbench
                |             Set TheKinWorkbench = CATIA.ActiveDocument.GetWorkbench ( "KinematicsWorkbench" )
                |             Dim TheMechanismsList As Mechanisms
                |             Set TheMechanismsList = TheKinWorkbench.Mechanisms

        :rtype: Mechanisms
        """

        return Mechanisms(self.kinematics_workbench.Mechanisms)

    def __repr__(self):
        return f'KinematicsWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.knowledge_interfaces.unit import Unit
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Units(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Units
                | 
                | Represents the collection of Units.
                | This collection can be retrieved via any collection of parameters (method
                | Units).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Unit)
        self.units = com_object

    def item(self, i_index: cat_variant) -> Unit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As Unit
                | 
                |     Returns a unit using its index or its name from the from the Parameters
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the unit to retrieve from the collection
                |             of parameters. As a numerics, this index is the rank of the unit in the
                |             collection. The index of the first unit in the collection is 1, and the index
                |             of the last parameter is Count. As a string, it is the name you assigned to the
                |             parameter using the 
                | 
                |         AnyObject.Name property or when creating the parameter.
                |         
                |     Example:
                |         This example retrieves the millimeter unit in the units
                |         collection:
                | 
                |          Set unitmm = units.Item("mm")

        :param cat_variant i_index:
        :rtype: Unit
        """
        return Unit(self.units.Item(i_index))

    def __getitem__(self, n: int) -> Unit:
        if (n + 1) > self.count:
            raise StopIteration

        return Unit(self.units.Item(n + 1))

    def __iter__(self) -> Iterator[Unit]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Units(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_groupable import PSPGroupable
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class PSPGroup(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspGroup
                | 
                | Represent the Group.
                | Role: It manages group members in making logical relationship.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_group = com_object

    @property
    def members(self) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Members() As PspListOfObjects (Read Only)
                | 
                |     Returns a list of Members of the Group.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspGroup  
                |          Dim objArg1 As PspListOfObjects
                |           ...
                |          Set ObjArg1 = objThisIntf.Members

        :rtype: PSPListOfObjects
        """

        return PSPListOfObjects(self.psp_group.Members)

    def add_member(self, i_groupable: PSPGroupable) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddMember(PspGroupable iGroupable)
                | 
                |     Adds a member to the group.
                | 
                |     Parameters:
                | 
                |         iGroupable
                |             Member to add 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspGroup  
                |          Dim objArg1 As PspGroupable
                |           ...
                |           objThisIntf.AddMember objArg1

        :param PSPGroupable i_groupable:
        :rtype: None
        """
        return self.psp_group.AddMember(i_groupable.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_member'
        # # vba_code = """
        # # Public Function add_member(psp_group)
        # #     Dim iGroupable (2)
        # #     psp_group.AddMember iGroupable
        # #     add_member = iGroupable
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_member(self, i_groupable: PSPGroupable) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveMember(PspGroupable iGroupable)
                | 
                |     Removes a member from the group.
                | 
                |     Parameters:
                | 
                |         iGroupable
                |             a member to be removed 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspGroup  
                |          Dim objArg1 As PspGroupable
                |           ...
                |           objThisIntf.RemoveMember objArg1

        :param PSPGroupable i_groupable:
        :rtype: None
        """
        return self.psp_group.RemoveMember(i_groupable.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_member'
        # # vba_code = """
        # # Public Function remove_member(psp_group)
        # #     Dim iGroupable (2)
        # #     psp_group.RemoveMember iGroupable
        # #     remove_member = iGroupable
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPGroup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.system_interfaces.collection import Collection
from pycatia.system_interfaces.setting_controller import SettingController


class SettingControllers(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     SettingControllers
                | 
                | A collection of all the setting controllers objects currently managed by the
                | application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=SettingController)
        self.setting_controllers = com_object
        self.child_object = SettingController

    def item(self, i_index: str) -> SettingController:
        """


        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATBSTR iIndex) As SettingController
                | 
                |     Returns a setting controller using its name from the setting controllers
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The name of the window to retrieve from the collection of setting
                |             controller. As a string. 
                | 
                |     Returns:
                |         The retrieved setting controller.

        :param str i_index: See the "Setting Controller Reference" in your CAA Visual Basic Help file for string references.
        :rtype: SettingController
        """
        return SettingController(self.setting_controllers.Item(i_index))

    def __getitem__(self, n: int) -> SettingController:
        if (n + 1) > self.count:
            raise StopIteration

        return SettingController(self.setting_controllers.Item(n + 1))

    def __iter__(self) -> Iterator[SettingController]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'SettingControllers(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import Union

from pycatia.cat_mat_interfaces.material import Material
from pycatia.mec_mod_interfaces.body import Body
from pycatia.mec_mod_interfaces.hybrid_body import HybridBody
from pycatia.mec_mod_interfaces.part import Part
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class MaterialManager(AnyObject):
    """
    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     MaterialManager
            |
            | Interface to manage material manager object.
            | Role: A material manager is used to manage materials application
            | on geometrical objects.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.material_manager = com_object

    def apply_material_on_body(self, i_body: Body, i_material: Union[Material, None], i_link_mode: int = 0) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyMaterialOnBody(Body iBody,
                | Material iMaterial,
                | short iLinkMode)
                |
                |     Apply a Material on a Body. If Material is NULL, deletes
                |     the material already applied on the Body.

        :param Body i_body:
        :param Material i_material:
        :param int i_link_mode:
        :rtype: None
        """
        self.material_manager.ApplyMaterialOnBody(
            i_body.com_object,
            None if i_material is None else i_material.com_object,
            i_link_mode,
        )

    def apply_material_on_hybrid_body(
            self,
            i_hybrid_body: HybridBody,
            i_material: Union[Material, None],
            i_link_mode: int = 0,
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyMaterialOnHybridBody(HybridBody iHybridBody,
                | Material iMaterial,
                | short iLinkMode)
                |
                |     Apply a Material on a Hybrid Body. If Material is NULL,
                |     deletes the material already applied on the Hybrid Body

        :param HybridBody i_hybrid_body:
        :param Material i_material:
        :param int i_link_mode:
        :rtype: None
        """
        self.material_manager.ApplyMaterialOnHybridBody(
            i_hybrid_body.com_object,
            None if i_material is None else i_material.com_object,
            i_link_mode,
        )

    def apply_material_on_part(
            self, i_part: Part, i_material: Union[Material, None], i_link_mode: int = 0
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyMaterialOnPart(Part iPart,
                | Material iMaterial,
                | short iLinkMode)
                |
                |     Apply a Material on a Part. If Material is NULL, deletes
                |     the material already applied on the Part

        :param Part i_part:
        :param Material i_material:
        :param int i_link_mode:
        :rtype: None
        """
        self.material_manager.ApplyMaterialOnPart(
            i_part.com_object,
            None if i_material is None else i_material.com_object,
            i_link_mode,
        )

    def apply_material_on_product(
            self,
            i_product: Product,
            i_material: Union[Material, None],
            i_link_mode: int = 0,
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyMaterialOnProduct(Product iProduct,
                | Material iMaterial,
                | short iLinkMode)
                |
                |     Apply a Material on a Product. If Material is NULL,
                |     deletes the material already applied on the Product

        :param Product i_product:
        :param Material i_material:
        :param int i_link_mode:
        :rtype: None
        """
        self.material_manager.ApplyMaterialOnProduct(
            i_product.com_object,
            None if i_material is None else i_material.com_object,
            i_link_mode,
        )

    def apply_material_on_user_material(
            self,
            i_user_material: AnyObject,
            i_material: Union[Material, None],
            i_link_mode: int = 0,
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyMaterialOnUserMaterial(AnyObject iUserMaterial,
                | Material iMaterial,
                | short iLinkMode)
                |
                |     Apply a Material on a User Material (Analysis entity).
                |     Warning:
                |     iUserMaterial should be a CATIAAnalysisEntity object. If
                |     Material is NULL, deletes the material already applied on
                |     the User Material

        :param AnyObject i_user_material:
        :param Material i_material:
        :param int i_link_mode:
        :rtype: None
        """
        self.material_manager.ApplyMaterialOnUserMaterial(
            i_user_material,
            None if i_material is None else i_material.com_object,
            i_link_mode,
        )

    def get_material_on_body(self, i_body: Body) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMaterialOnBody(Body iBody,
                | Material oMaterial)
                |
                |     Get a Material on a Body. Material returned is NULL if no
                |     material is applied on the Body

        :param Body i_body:
        :param Material o_material:
        :rtype: None
        """
        vba_function_name = "get_material_on_body"
        vba_code = f"""        
        Public Function {vba_function_name}(material_manager, body)
            Dim material
            material_manager.GetMaterialOnBody body, material
            Set {vba_function_name} = material
        End Function
        """
        system_service = self.application.system_service
        return Material(
            system_service.evaluate(
                vba_code, 0, vba_function_name, [self.com_object, i_body.com_object]
            )
        )

    def get_material_on_hybrid_body(self, i_hybrid_body: HybridBody) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMaterialOnHybridBody(HybridBody iHybridBody,
                | Material oMaterial)
                |
                |     Get a Material on a Hybrid Body. Material returned is
                |     NULL if no material is applied on the Hybrid Body

        :param HybridBody i_hybrid_body:
        :param Material o_material:
        :rtype: None
        """
        vba_function_name = "get_material_on_hybrid_body"
        vba_code = f"""        
        Public Function {vba_function_name}(material_manager, hybrid_body)
            Dim material
            material_manager.GetMaterialOnHybridBody hybrid_body, material
            Set {vba_function_name} = material
        End Function
        """
        system_service = self.application.system_service
        return Material(
            system_service.evaluate(
                vba_code,
                0,
                vba_function_name,
                [self.com_object, i_hybrid_body.com_object],
            )
        )

    def get_material_on_part(self, i_part: Part) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMaterialOnPart(Part iPart,
                | Material oMaterial)
                |
                |     Get a Material on a Part. Material returned is NULL if no
                |     material is applied on the Part

        :param Part i_part:
        :param Material o_material:
        :rtype: None
        """
        vba_function_name = "get_material_on_part"
        vba_code = f"""        
        Public Function {vba_function_name}(material_manager, part)
            Dim material
            material_manager.GetMaterialOnPart part, material
            Set {vba_function_name} = material
        End Function
        """
        system_service = self.application.system_service
        return Material(
            system_service.evaluate(
                vba_code, 0, vba_function_name, [self.com_object, i_part.com_object]
            )
        )

    def get_material_on_product(self, i_product: Product) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMaterialOnProduct(Product iProduct,
                | Material oMaterial)
                |
                |     Get a Material on a Product. Material returned is NULL if
                |     no material is applied on the Product

        :param Product i_product:
        :param Material o_material:
        :rtype: None
        """
        vba_function_name = "get_material_on_product"
        vba_code = f"""        
        Public Function {vba_function_name}(material_manager, product)
            Dim material
            material_manager.GetMaterialOnProduct product, material
            Set {vba_function_name} = material
        End Function
        """
        system_service = self.application.system_service
        return Material(
            system_service.evaluate(
                vba_code, 0, vba_function_name, [self.com_object, i_product.com_object]
            )
        )

    def get_material_on_user_material(self, i_user_material: AnyObject) -> Material:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMaterialOnUserMaterial(AnyObject iUserMaterial,
                | Material oMaterial)
                |
                |     Get a Material on a User Material (Analysis entity).
                |     Warning: iUserMaterial should be a CATIAAnalysisEntity
                |     object. Material returned is NULL if no material is
                |     applied on the User Material

        :param AnyObject i_user_material:
        :param Material o_material:
        :rtype: None
        """
        vba_function_name = "get_material_on_user_material"
        vba_code = f"""        
        Public Function {vba_function_name}(material_manager, user_material)
            Dim material
            material_manager.GetMaterialOnUserMaterial user_material, material
            Set {vba_function_name} = material
        End Function
        """
        system_service = self.application.system_service
        return Material(
            system_service.evaluate(
                vba_code,
                0,
                vba_function_name,
                [self.com_object, i_user_material.com_object],
            )
        )

    def replace_material_links(
            self, i_material1: Material, i_material2: Material
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReplaceMaterialLinks(Material iMaterial1,
                | Material iMaterial2)
                |
                |     In current session, replace all links towards a material 1
                |     with a link towards an other material 2. N.B. Both
                |     materials entered should be in a material library.

        :param Material i_material1:
        :param Material i_material2:
        :rtype: None
        """
        self.material_manager.ReplaceMaterialLinks(i_material1, i_material2)

    def __repr__(self):
        return f'MaterialManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.general_knowledge_interfaces.expert_rule_base_component_runtime import ExpertRuleBaseComponentRuntime
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ExpertRuleBaseComponentRuntimes(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ExpertRuleBaseComponentRuntimes
                | 
                | Represents the collection of ExpertRuleBase (ExpertChecks, ExpertRules, and
                | ExpertRuleSets) components.
                | This collection can be seen flattened (with Item/Count) or hierarchised (with
                | ShallowItem/ShallowCount).
                | 
                | Be careful : the flattened view can be misleading. For instance, if there are
                | two ExpertChecks with the same name, you will be able to access only one of
                | them (with the methods ExpertRuleBaseComponentRuntimes.Item and
                | ExpertRuleBaseComponentRuntimes.Remove )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ExpertRuleBaseComponentRuntime)
        self.expert_rule_base_component_runtimes = com_object

    def item(self, i_index: cat_variant) -> ExpertRuleBaseComponentRuntime:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As
                | ExpertRuleBaseComponentRuntime
                | 
                |     Returns a RuleBase component using its index or its name from the entire
                |     RuleBase collection.
                | 
                |     If several Expert components have the same name, the use of name is
                |     unpredicted.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Rule Base component to retrieve from
                |             the collection of Rule Base Components. As a numerics, this index is the rank
                |             of the Rule Base Component in the collection. The index of the first component
                |             in the collection is 1, and the index of the last component is Count. As a
                |             string, it is the name you assigned to the component using the
                |
                |         AnyObject.Name property or when creating the component.
                |         
                |     Returns:
                |         The retrieved Rule base component. 
                | 
                | Example:
                |     This example retrieves the last component in a RuleSet
                |     collection.
                | 
                |       Dim lastRuleBaseComponent as
                |       ExpertRuleBaseComponentRuntime
                |       Set lastRuleBaseComponent = RuleSet.Item(RuleCollection.Count)

        :param cat_variant i_index:
        :rtype: ExpertRuleBaseComponentRuntime
        """
        return ExpertRuleBaseComponentRuntime(self.expert_rule_base_component_runtimes.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Expert component from the Rule Base collection. If the expert
                |     component is a RuleSet all the rules, checks and rulesets embedded in the
                |     Ruleset will be also removed.
                | 
                |     If several Expert components have the same name, the use of name is
                |     unpredicted.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the component to retrieve from the
                |             collection. As a numerics, this index is the rank of the expert component in
                |             the collection. The index of the first component in the collection is 1, and
                |             the index of the last component is Count. As a string, it is the name you
                |             assigned to the component using the 
                | 
                |         AnyObject.Name property or when creating the Expert component.
                |         
                | 
                | Example:
                |     This example removes the Expert component named density from the relations
                |     collection.
                | 
                |      Dim CATDocs As Document
                |      Set CATDocs   = CATIA.Documents
                |      Dim partdoc As PartDocument
                |      Set partdoc   = CATDocs.Add("CATPart")
                |      Dim part As Part
                |      Set part      = partdoc.Part
                |      Set massCheck    = part.Relations.Item("RuleBase").RuleSet.ExpertRuleBaseComponentRuntimes.Remove("density")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.expert_rule_base_component_runtimes.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(expert_rule_base_component_runtimes)
        # #     Dim iIndex (2)
        # #     expert_rule_base_component_runtimes.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def shallow_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ShallowCount() As long
                | 
                |     Returns the number of first-level-depth objects in the collection. This is
                |     handy to scan the objects in a collection.
                | 
                |     Example:
                |         This example retrieves in ObjectNumber the number of objects currently
                |         gathered in MyCollection.
                | 
                |          ObjectNumber = MyCollection.ShallowCount

        :rtype: int
        """
        return self.expert_rule_base_component_runtimes.ShallowCount()

    def shallow_item(self, i_index: cat_variant) -> ExpertRuleBaseComponentRuntime:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ShallowItem(CATVariant iIndex) As
                | ExpertRuleBaseComponentRuntime
                | 
                |     Returns a first-level-depth RuleBase component using its index or its name
                |     from the RuleBase collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Rule Base component to retrieve from
                |             the collection of Rule Base Components. As a numerics, this index is the rank
                |             of the Rule Base Component in the collection. The index of the first component
                |             in the collection is 1, and the index of the last component is ShallowCount. As
                |             a string, it is the name you assigned to the component using the
                |             
                | 
                |         AnyObject.Name property or when creating the component.
                |         
                |     Returns:
                |         The retrieved Rule base component. 
                | 
                | Example:
                |     This example retrieves the last component in a RuleSet
                |     collection.
                | 
                |       Dim lastRuleBaseComponent as
                |       ExpertRuleBaseComponentRuntime
                |       Set lastRuleBaseComponent = RuleSet.ShallowItem(RuleCollection.ShallowCount)

        :param cat_variant i_index:
        :rtype: ExpertRuleBaseComponentRuntime
        """
        return ExpertRuleBaseComponentRuntime(self.expert_rule_base_component_runtimes.ShallowItem(i_index))

    def shallow_remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ShallowRemove(CATVariant iIndex)
                | 
                |     Removes an first-level-depth Expert component from the Rule Base
                |     collection. If the expert component is a RuleSet all the rules, checks and
                |     rulesets embedded in the Ruleset will be also removed.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the component to retrieve from the
                |             collection. As a numerics, this index is the rank of the expert component in
                |             the collection. The index of the first component in the collection is 1, and
                |             the index of the last component is ShallowCount. As a string, it is the name
                |             you assigned to the component using the 
                | 
                |         AnyObject.Name property or when creating the Expert component.
                |         
                | 
                | Example:
                |     This example removes the Expert component named density from the relations
                |     collection.
                | 
                |      Dim CATDocs As Document
                |      Set CATDocs   = CATIA.Documents
                |      Dim partdoc As PartDocument
                |      Set partdoc   = CATDocs.Add("CATPart")
                |      Dim part As Part
                |      Set part      = partdoc.Part
                |      Set massCheck    = part.Relations.Item("RuleBase").RuleSet.ExpertRuleBaseComponentRuntimes.ShallowRemove("density")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.expert_rule_base_component_runtimes.ShallowRemove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'shallow_remove'
        # # vba_code = """
        # # Public Function shallow_remove(expert_rule_base_component_runtimes)
        # #     Dim iIndex (2)
        # #     expert_rule_base_component_runtimes.ShallowRemove iIndex
        # #     shallow_remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ExpertRuleBaseComponentRuntimes(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_igp_setup_interfaces.generic_action import GenericAction
from pycatia.system_interfaces.any_object import AnyObject


class GenericActionFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     GenericActionFactory
                | 
                | Interface representing GenericAction factory.
                | 
                | Role: This allows the creation of a GenericAction under an
                | Operation
                | The following code snippet can be used to obtain a GenericActionFactory from a
                | selected Operation
                | 
                |    Dim oSelectAct As Activity
                |    set oSelectAct = CATIA.ActiveDocument.Selection.FindObject("CATIAActivity")
                |    Dim objGenActFact As GenericActionFactory
                |    set objGenActFact = oSelectAct.GetTechnologicalObject("GenericActionFactory")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.generic_action_factory = com_object

    def create_generic_action(
            self,
            i_action_type: str,
            i_before: bool,
            i_reference_activity: Activity
    ) -> GenericAction:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateGenericAction(CATBSTR iActionType,
                | boolean iBefore,
                | Activity iReferenceActivity) As GenericAction
                | 
                |     Creates an Action based on the specified type
                | 
                |     Parameters:
                | 
                |         iActionType
                |             Type of Action to be created. 
                |         iBefore
                |             Created Action can be Predecessor/Successor. 
                |         iReferenceActivitiy
                |             The Reference Activity Before/After which the Action needs to be
                |             created. 
                |         oGenericAction
                |             Created Action. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             Action is successfully created and the interface pointer is
                |             successfully returned
                |         E_FAIL
                |             Action was successfully created, but the interface query
                |             failed
                |         E_NOINTERFACE
                |             Action was successfully created, but the it doesn't implement the
                |             requested interface
                |         E_OUTOFMEMORY
                |             The component allocation failed
                | 
                |     Example:
                |
                |            Dim objGenActFact As GenericActionFactory
                |                   ......
                |            Dim refAct As Activity
                |            Dim objGenAct as GenericAction CATIASelection
                |                   ......
                |            Before = TRUE
                |            set refAct = CATIA.ActiveDocument.Selection.FindObject("CATIAActivity")
                |            set objGenAct = objGenActFact.CreateGenericAction("DNBIgpSpotWeld", False, refAct)
                |            ..

        :param str i_action_type:
        :param bool i_before:
        :param Activity i_reference_activity:
        :rtype: GenericAction
        """
        return GenericAction(
            self.generic_action_factory.CreateGenericAction(
                i_action_type,
                i_before,
                i_reference_activity.com_object
            )
        )

    def __repr__(self):
        return f'GenericActionFactory(name="{self.name}")'
